Learn R Programming

adehabitatMA (version 0.3.12)

labcon: Labelling Connected Features

Description

This function attributes unique labels to pixels belonging to connected features on a map of class SpatialPixelsDataFrame.

Usage

labcon(x)

Arguments

x

an object of class SpatialPixelsDataFrame with one column

Value

Returns a matrix of class asc, of type "factor", with a number of levels equals to the number of connected components

See Also

SpatialPixelsDataFrame-class for further information on the class SpatialPixelsDataFrame

Examples

Run this code
# NOT RUN {
data(lynxjura)
sa <- lynxjura$map[,1]

## build an image with separate components
sa[[1]][sa[[1]]<50] <- NA

## show the connected components
image(sa)
image(labcon(sa))


# }

Run the code above in your browser using DataLab